@@ -24,24 +24,26 @@ fn main() -> Result<()> {
     let mut open_errors: u8 = 0;
 
     loop {
-	if let Err(e) = f.follow() {
-	    match e {
-		StaartError::IO(err) if err.kind() == std::io::ErrorKind::NotFound => {
-		    if open_errors >= OPEN_ERR_LIMIT {
-			eprintln!("Failed to open: {}, more than {} times. Exiting!", path.display(), open_errors);
-			std::process::exit(1);
-		    } else {
-			open_errors += 1;
-		    }
-		},
-		StaartError::Utf8(_) => {
-		    eprintln!("encountered non-utf8 bytes on read")
-		},
-		_ => {
-		    return Err(e)
-		}
-	    }
-	}
+        if let Err(e) = f.follow() {
+            match e {
+                StaartError::IO(err) if err.kind() == std::io::ErrorKind::NotFound => {
+                    if open_errors >= OPEN_ERR_LIMIT {
+                        eprintln!(
+                            "Failed to open: {}, more than {} times. Exiting!",
+                            path.display(),
+                            open_errors
+                        );
+                        std::process::exit(1);
+                    } else {
+                        open_errors += 1;
+                    }
+                }
+                StaartError::Utf8(_) => {
+                    eprintln!("encountered non-utf8 bytes on read")
+                }
+                _ => return Err(e),
+            }
+        }
 
         sleep(DEFAULT_DELAY);
     }
